@@ -9,10 +9,24 @@ file that was distributed with this source code.
 Written by Temuri Takalandze <t.takalandze@omedia.dev>, September 2021
 """
 
+# pylint: disable=R0903
+
 
 class _Input:
+    """
+    Configuration class for the AI Processor's input data.
+    """
+
     # DO NOT touch these attributes! They will be initialized later.
     TIME_SERIES = {}
+
+
+class _Parameters:
+    """
+    Configuration class for the AI Processor's parameters.
+    """
+
+    # DO NOT touch these attributes! They will be initialized later.
     TAGS = {}
 
 
@@ -27,3 +41,4 @@ class Config:
     DESCRIPTION = None
     MEASUREMENTS = []
     INPUT = _Input()
+    PARAMETERS = _Parameters()
